@@ -8,7 +8,7 @@ use Carp;
 use URI::Escape;
 
 use vars qw($VERSION $bad_request_doc);
-$VERSION = '0.37';
+$VERSION = '0.39';
 
 =head1 NAME
 
@@ -215,7 +215,8 @@ sub background {
         POSIX::setsid()
             or croak "Can't start a new session: $!";
     }
-    $self->run(@_);
+    $self->run(@_); # should never return
+    exit;           # just to be sure
 }
 
 =head2 run [ARGUMENTS]
@@ -574,7 +575,7 @@ yourself in subclasses.
 sub print_banner {
     my $self = shift;
 
-    print(    __PACKAGE__
+    print( ref($self) 
             . ": You can connect to your server at "
             . "http://localhost:"
             . $self->port
@@ -660,7 +661,6 @@ sub setup_listener {
         )
         or croak "bind to @{[$self->host||'*']}:@{[$self->port]}: $!";
     listen( HTTPDaemon, SOMAXCONN ) or croak "listen: $!";
-
 }
 
 
